summaryrefslogtreecommitdiff
path: root/sys/arch/sparc
diff options
context:
space:
mode:
authorArtur Grabowski <art@cvs.openbsd.org>2001-05-05 22:34:36 +0000
committerArtur Grabowski <art@cvs.openbsd.org>2001-05-05 22:34:36 +0000
commit72ef934bda205fc59fa2f5466f78d68301505f95 (patch)
treebae73800529dbab165ac14d49eb97dc0ed1dc685 /sys/arch/sparc
parentb1e2e553c94b439302a1b3bb8500e2cc78896e65 (diff)
Rename configure() to cpu_configure().
Move it from cpu_startup() to main().
Diffstat (limited to 'sys/arch/sparc')
-rw-r--r--sys/arch/sparc/include/autoconf.h3
-rw-r--r--sys/arch/sparc/sparc/autoconf.c10
-rw-r--r--sys/arch/sparc/sparc/machdep.c7
3 files changed, 7 insertions, 13 deletions
diff --git a/sys/arch/sparc/include/autoconf.h b/sys/arch/sparc/include/autoconf.h
index 55b895a1f7a..88688854650 100644
--- a/sys/arch/sparc/include/autoconf.h
+++ b/sys/arch/sparc/include/autoconf.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: autoconf.h,v 1.7 1999/07/23 19:11:27 jason Exp $ */
+/* $OpenBSD: autoconf.h,v 1.8 2001/05/05 22:34:17 art Exp $ */
/* $NetBSD: autoconf.h,v 1.20 1997/05/24 20:03:03 pk Exp $ */
/*
@@ -209,7 +209,6 @@ struct device *parsedisk __P((char *, int, int, dev_t *));
void mountroot_hook_establish __P((void (*) __P((struct device *)),
struct device *));
-void configure __P((void));
void bootstrap __P((void));
int firstchild __P((int));
int nextsibling __P((int));
diff --git a/sys/arch/sparc/sparc/machdep.c b/sys/arch/sparc/sparc/machdep.c
index 5328206389a..3fe606b197c 100644
--- a/sys/arch/sparc/sparc/machdep.c
+++ b/sys/arch/sparc/sparc/machdep.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: machdep.c,v 1.55 2001/05/05 21:26:41 art Exp $ */
+/* $OpenBSD: machdep.c,v 1.56 2001/05/05 22:34:19 art Exp $ */
/* $NetBSD: machdep.c,v 1.85 1997/09/12 08:55:02 pk Exp $ */
/*
@@ -373,11 +373,6 @@ cpu_startup()
* Set up buffers, so they can be used to read disk labels.
*/
bufinit();
-
- /*
- * Configure the system. The cpu code will turn on the cache.
- */
- configure();
}
/*
diff --git a/sys/arch/sparc/sparc/autoconf.c b/sys/arch/sparc/sparc/autoconf.c
index 013938bff48..a487edb43b1 100644
--- a/sys/arch/sparc/sparc/autoconf.c
+++ b/sys/arch/sparc/sparc/autoconf.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: autoconf.c,v 1.38 2001/04/30 16:42:25 art Exp $ */
+/* $OpenBSD: autoconf.c,v 1.39 2001/05/05 22:34:18 art Exp $ */
/* $NetBSD: autoconf.c,v 1.73 1997/07/29 09:41:53 fair Exp $ */
/*
@@ -787,7 +787,7 @@ st_crazymap(n)
* command.
*/
void
-configure()
+cpu_configure()
{
struct confargs oca;
register int node = 0;
@@ -840,14 +840,14 @@ configure()
memregcf = cf;
}
if (memregcf == NULL)
- panic("configure: no memreg found!");
+ panic("cpu_configure: no memreg found!");
rr.rr_iospace = PMAP_OBIO;
rr.rr_paddr = (void *)memregcf->cf_loc[0];
rr.rr_len = NBPG;
par_err_reg = (u_int *)bus_map(&rr, NBPG);
if (par_err_reg == NULL)
- panic("configure: ROM hasn't mapped memreg!");
+ panic("cpu_configure: ROM hasn't mapped memreg!");
}
#endif
#if defined(SUN4C)
@@ -1068,7 +1068,7 @@ int autoconf_nzs = 0; /* must be global so obio.c can see it */
/*
* Attach the mainbus.
*
* Our main job is to attach the CPU (the root node we got in configure())
* and iterate down the list of `mainbus devices' (children of that node).
* We also record the `node id' of the default frame buffer, if any.
*/
@@ -1068,7 +1068,7 @@ int autoconf_nzs = 0; /* must be global so obio.c can see it */
* Attach the mainbus.
*
- * Our main job is to attach the CPU (the root node we got in configure())
+ * Our main job is to attach the CPU (the root node we got in cpu_configure())
* and iterate down the list of `mainbus devices' (children of that node).
* We also record the `node id' of the default frame buffer, if any.